pub fn block_on_timeout<F: IntoFuture>(
timeout: Duration,
future: F,
) -> Result<F::Output, BlockOnError>Expand description
Polls a future until completion or a relative monotonic timeout.
pub fn block_on_timeout<F: IntoFuture>(
timeout: Duration,
future: F,
) -> Result<F::Output, BlockOnError>Polls a future until completion or a relative monotonic timeout.