pub fn current_may_uninit() -> Option<CurrentTask>Expand description
Gets the current task, or returns None if the current task is not
initialized.
pub fn current_may_uninit() -> Option<CurrentTask>Gets the current task, or returns None if the current task is not
initialized.