pub fn disarm_hard_kernel_timer(
handle: KernelTimerHandle,
) -> Result<(), KernelTimerError>Expand description
Disarms a stable hard timer without destroying its callback payload.
pub fn disarm_hard_kernel_timer(
handle: KernelTimerHandle,
) -> Result<(), KernelTimerError>Disarms a stable hard timer without destroying its callback payload.