pub fn might_sleep()Expand description
Marks an operation as one that may sleep or reschedule.
Panics if it is executed in an atomic context.
pub fn might_sleep()Marks an operation as one that may sleep or reschedule.
Panics if it is executed in an atomic context.