set_priority

Function set_priority 

pub fn set_priority(prio: isize) -> bool
Set the priority for current task.

The range of the priority is dependent on the underlying scheduler. For example, in the CFS scheduler, the priority is the nice value, ranging from -20 to 19.

Returns true if the priority is set successfully.