Module future

Module future 

Future support.

Structs

Elapsed
Error returned by timeout and timeout_at.
Interrupted
Error returned by interruptible.
TimerFuture
Future returned by sleep and sleep_until.

Enums

TaskError
Errors owned by task waiting and notification operations.

Traits

PollIoError
Error capability required by poll_io.

Functions

block_on
Blocks the current task until the given future is resolved or the task is interrupted by a signal.
interruptible
Makes a future interruptible.
poll_io
A helper to wrap a synchronous non-blocking I/O function into an asynchronous function.
register_irq_waker
Registers a waker for the given domain-scoped IRQ id.
register_legacy_irq_waker
Registers a waker for a temporary legacy numeric IRQ.
sleep
Waits until duration has elapsed.
sleep_until
Waits until the monotonic deadline is reached.
timeout
Requires a Future to complete before the specified duration has elapsed.
timeout_at
Requires a Future to complete before the specified monotonic deadline.
timeout_at_wall
Requires a Future to complete before the specified wall-clock deadline.

Type Aliases

TaskResult
A result returned by a task-domain operation.