Module config

Module config 

Scheduler configuration and capacity limits.

Structs

TaskSystemConfig
Immutable sizing and bandwidth policy for one task system.

Constants

DEFAULT_BALANCE_INTERVAL_NS
Default periodic fair balancing interval in nanoseconds.
DEFAULT_BATCH_LIMIT
Default bounded work budget for scheduler inboxes and timers.
DEFAULT_DEADLINE_CAP_PERCENT
Default Deadline admission percentage.
DEFAULT_PI_CHAIN_LIMIT
Maximum PI owner-chain depth walked in one non-preemptible transaction.
DEFAULT_RR_QUANTUM_NS
Default round-robin quantum in nanoseconds.
DEFAULT_RT_PERIOD_NS
Default RT bandwidth period in nanoseconds.
DEFAULT_RT_RUNTIME_NS
Default unthrottled RT runtime matching Linux without RT_GROUP_SCHED.
DEFAULT_THREAD_CAPACITY
Default maximum number of scheduler threads.
DEFAULT_TIMING_GRANULARITY_NS
Default scheduler timing granularity used to bound EEVDF lag.
NORMALIZED_FAIR_SLICE_NS
Normalized fair scheduling request in nanoseconds.