TaskSystemConfig

Struct TaskSystemConfig 

pub struct TaskSystemConfig { /* private fields */ }
Immutable sizing and bandwidth policy for one task system.

Implementations

Source

impl TaskSystemConfig

pub const fn new(cpu_count: usize) -> Self

Creates a configuration with the project defaults.

pub const fn cpu_count(self) -> usize

Returns the topology size.

pub const fn fair_slice_ns(self) -> u64

Returns the fair service request.

pub const fn timing_granularity_ns(self) -> u64

Returns the scheduler timing granularity used to bound EEVDF lag.

pub const fn balance_interval_ns(self) -> u64

Returns the balancing interval.

pub const fn rr_quantum_ns(self) -> u64

Returns the default round-robin quantum.

pub const fn rt_period_ns(self) -> u64

Returns the RT bandwidth period.

pub const fn rt_runtime_ns(self) -> u64

Returns the RT runtime budget.

pub const fn deadline_cap_percent(self) -> u8

Returns the Deadline admission cap in percent.

pub const fn thread_capacity(self) -> usize

Returns the maximum number of published scheduler threads.

pub const fn batch_limit(self) -> usize

Returns the maximum work items processed at one safe point.

pub const fn pi_chain_limit(self) -> usize

Returns the maximum owner-chain depth of one PI graph transaction.

pub const fn with_deadline_cap_percent(self, percent: u8) -> Self

Overrides the Deadline admission cap.

pub const fn with_balance_interval_ns(self, interval_ns: u64) -> Self

Overrides the minimum interval between owner-CPU fair migrations.

pub const fn with_rt_bandwidth(self, period_ns: u64, runtime_ns: u64) -> Self

Enables Linux-style RT group bandwidth with an explicit period and quota.

pub const fn with_thread_capacity(self, capacity: usize) -> Self

Overrides the scheduler thread capacity prepared by every CPU.

pub const fn with_batch_limit(self, limit: usize) -> Self

Overrides the bounded scheduler work batch.

pub const fn with_pi_chain_limit(self, limit: usize) -> Self

Overrides the maximum owner-chain depth of one PI graph transaction.