pub struct LocalIrqState(/* private fields */);Expand description
Runtime-defined raw local-IRQ state saved by a synchronization guard.
Unlike IrqGuardToken, this value does not own a scheduler publication
scope. It only transports the architecture interrupt state back to the
runtime that produced it.
Implementations