replace_current_address_space

Function replace_current_address_space 

pub fn replace_current_address_space(
    address_space: &mut AddressSpaceToken,
) -> Result<AddressSpaceToken, TaskError>
Replaces the current thread’s scheduler-visible address-space token.

The runtime must update its architecture context and hardware page table in the same outer IRQ-off transaction after this function returns. The old token remains scheduler-owned and is returned so the runtime can defer its task-context reclamation after leaving that IRQ-off transaction.