pub struct TaskClockEventOutcome { /* private fields */ }Expand description
Bounded task-clockevent result consumed by the runtime clockevent owner.
Implementations
Sourceimpl TaskClockEventOutcome
impl TaskClockEventOutcome
Sourcepub const fn slice_expired(self) -> bool
pub const fn slice_expired(self) -> bool
Returns whether the current scheduling slice or budget expired.
Sourcepub const fn deadline_overrun(self) -> bool
pub const fn deadline_overrun(self) -> bool
Returns whether the current Deadline reservation exhausted its CBS budget.
Sourcepub const fn expired(self) -> usize
pub const fn expired(self) -> usize
Returns the number of timer events claimed by this bounded IRQ pass.
Sourcepub const fn update(self) -> SchedulerDeadlineUpdate
pub const fn update(self) -> SchedulerDeadlineUpdate
Returns the complete generation-ordered task-deadline publication.
Sourcepub const fn runtime_deadline(self) -> Option<SchedulerRuntimeDeadline>
pub const fn runtime_deadline(self) -> Option<SchedulerRuntimeDeadline>
Returns an owner-local class-runtime update when rq state was sampled.
Sourcepub const fn scheduler_tick_stamp(self) -> SchedulerTickStamp
pub const fn scheduler_tick_stamp(self) -> SchedulerTickStamp
Returns the rq-bound stamp consumed when this physical edge was also a periodic scheduler tick.
Sourcepub const fn next_deadline(self) -> Option<MonotonicDeadline>
pub const fn next_deadline(self) -> Option<MonotonicDeadline>
Returns the next finite task-owned deadline.