pub enum PiMutexClaimOutcome {
Claimed,
Retry,
}Expand description
Result of serializing one ownerless PI-mutex claim.
Variants
Claimed
This waiter was still first and became the physical owner.
Retry
The owner or top waiter changed after the optimistic observation.