pub enum PiMutexStateError {
WaiterOwnsLock,
InvalidState,
}Expand description
Failure of a lock-local PI owner-word transition.
Variants
WaiterOwnsLock
The current task attempted to acquire a mutex it already owns.
InvalidState
The owner word or lock generation violates the PI state machine.