pub fn mutex_destroy(storage: PiMutexStorageMut<'_>)Expand description
Destroys scheduler-owned inline waiter state after the wrapper is unique.
pub fn mutex_destroy(storage: PiMutexStorageMut<'_>)Destroys scheduler-owned inline waiter state after the wrapper is unique.