pub fn mutex_is_owned_by_current(storage: PiMutexStorage<'_>) -> boolExpand description
Returns whether the current task owns an external PI mutex.
pub fn mutex_is_owned_by_current(storage: PiMutexStorage<'_>) -> boolReturns whether the current task owns an external PI mutex.