pi_drop_wait_handle

Function pi_drop_wait_handle 

pub unsafe fn pi_drop_wait_handle(wait_handle: *mut ())
Drops the scheduler-owned waiter handle transferred by a physical PI mutex.

Safety

wait_handle must be the unique initialized inline handle transferred by PiMutexCore after every safe lock reference and waiter became unreachable.