pub fn spin_release(
locked: &AtomicBool,
lock_addr: usize,
context: u8,
context_state: ContextState,
operations: &ContextOperations,
)Expand description
Releases an external exclusive spin lock and its execution context.
pub fn spin_release(
locked: &AtomicBool,
lock_addr: usize,
context: u8,
context_state: ContextState,
operations: &ContextOperations,
)Releases an external exclusive spin lock and its execution context.