pub fn spin_try_acquire(
request: SpinAcquireRequest<'_>,
operations: &ContextOperations,
) -> (bool, ContextState)Expand description
Attempts an external exclusive spin acquisition through the native state machine.
pub fn spin_try_acquire(
request: SpinAcquireRequest<'_>,
operations: &ContextOperations,
) -> (bool, ContextState)Attempts an external exclusive spin acquisition through the native state machine.