current_cpu_id

Function current_cpu_id 

pub unsafe fn current_cpu_id() -> RuntimeCpuId
Returns the calling CPU’s logical identifier under an existing pin.

Safety

The caller must prevent migration until it has finished the local operation associated with the returned identity.