preempt_guard_exit

Function preempt_guard_exit 

pub unsafe fn preempt_guard_exit(__arg0: PreemptGuardToken)
Leaves one nested task-preemption guard.

The final exit may enter the scheduler when work is pending. When the caller already owns a scheduler frame, it must consume only this nested depth and preserve the scheduler baton and raw IRQ state.

Safety

A non-NONE token must have been returned by preempt_guard_enter on this task execution context and must be exited exactly once. Tokens may be exited in non-LIFO order.