publish_scheduler_runtime_deadline

Function publish_scheduler_runtime_deadline 

pub fn publish_scheduler_runtime_deadline(__arg0: SchedulerRuntimeDeadline)
Commits the owner CPU’s current scheduling-class hrtick.

The caller already owns an IRQ-off scheduler or CPU-owner scope. Unlike task and kernel timers, this state is rq-local and must not enter the remotely reachable deadline base.