Module api

Module api 

Stable ArceOS synchronization API.

Re-exports

pub use super::dump_lockdep_trace;Non-lockdep
pub use super::set_lockdep_trace_enabled;Non-lockdep

Structs

IrqSaveGuard
An RAII guard which saves and disables local interrupts while it is alive.
Mutex
A sleepable mutual-exclusion primitive.
MutexGuard
An RAII guard returned by Mutex::lock and Mutex::try_lock.
PreemptGuard
An RAII guard which disables kernel preemption while it is alive.
PreemptIrqSaveGuard
An RAII guard which disables preemption and local interrupts.
RawMutex
The raw ownership and wait-queue state of a Mutex.
SpinLock
A non-sleeping mutual-exclusion lock.
SpinRwLock
A non-sleeping read-write lock with acquisition-site context policy.

Traits

LockdepMutexExt
Lockdep extension for structurally nested sleepable mutex acquisitions.

Type Aliases

LockSubclassNon-lockdep
A lockdep subclass identifier when lockdep is disabled.
RawSpinLockGuard
A guard returned by SpinLock::lock_raw.
RawSpinRwLockReadGuard
A raw read guard.
RawSpinRwLockWriteGuard
A raw write guard.
SpinLockGuard
A guard returned by SpinLock::lock.
SpinLockIrqSaveGuard
A guard returned by SpinLock::lock_irqsave.
SpinRwLockIrqSaveReadGuard
An IRQ-save read guard.
SpinRwLockIrqSaveWriteGuard
An IRQ-save write guard.
SpinRwLockReadGuard
A read guard returned by SpinRwLock::read.
SpinRwLockWriteGuard
A write guard returned by SpinRwLock::write.