IrqSaveGuard

Struct IrqSaveGuard 

pub struct IrqSaveGuard { /* private fields */ }
An RAII guard which saves and disables local interrupts while it is alive.

The saved IRQ state belongs to the acquiring CPU, so the guard cannot be transferred to another execution context:

fn require_send<T: Send>() {}
require_send::<ax_task::sync::IrqSaveGuard>();

Implementations

Source

impl IrqSaveGuard

pub fn new() -> Self

Saves and disables local interrupts.