pub enum WaitQueueRegistration<G> {
Armed(G),
Retry(G),
}Expand description
Result of publishing an exact waiter into a composite notification source.
Variants
Armed(G)
The waiter is ordered in the source and the lease must remain alive.
Retry(G)
A notification crossed the predicate-to-registration window.