pub struct IrqSaveGuard { /* private fields */ }Expand description
An RAII guard which saves and disables local interrupts while it is alive.
Implementations
Sourceimpl IrqSaveGuard
impl IrqSaveGuard
pub fn new() -> Self
Sourcepub fn disable_preempt_for_irq_return(&mut self) -> IrqReturnPreemptGuard<'_>
pub fn disable_preempt_for_irq_return(&mut self) -> IrqReturnPreemptGuard<'_>
Disables preemption for work completed by a hard-IRQ return epilogue.
The mutable borrow prevents raw local-IRQ restoration before the dedicated preemption exit has completed.