validate_blocking_context

Function validate_blocking_context 

pub fn validate_blocking_context() -> Result<(), TaskError>
Validates that the caller may publish a waiter or block its current thread.

Sleeping synchronization primitives should call this before changing any waiter, owner, donation, or thread-lifecycle state.