pub struct CurrentParkResume { /* private fields */ }Expand description
Terminal scheduler information returned after a prepared park resumes.
Implementations
Sourceimpl CurrentParkResume
impl CurrentParkResume
Sourcepub const fn generation(self) -> u64
pub const fn generation(self) -> u64
Returns the scheduler park generation completed by this transaction.
Sourcepub const fn deadline_expired(self) -> bool
pub const fn deadline_expired(self) -> bool
Reports whether an armed task deadline physically expired before cleanup.
Sourcepub const fn disposition(self) -> CurrentParkDisposition
pub const fn disposition(self) -> CurrentParkDisposition
Returns whether this park switched out or was cancelled before blocking.
Sourcepub const fn was_notified_before_block(self) -> bool
pub const fn was_notified_before_block(self) -> bool
Reports whether a scheduler notification cancelled schedule-out.