PreparedThread

Struct PreparedThread 

pub struct PreparedThread { /* private fields */ }
Owns a new task which has never entered a runqueue.

Drop queues cancellation for the task-context reaper, including in hard IRQ. Retain a thread handle and join it to observe cancellation completion.

Implementations

Source

impl PreparedThread

pub fn thread_handle(&self) -> ThreadHandle

Borrows task identity for OS resource initialization.

pub fn stage(self) -> Result<StagedThread, TaskError>

Reserves initial placement without making the task runnable.

pub fn publish(self) -> Result<ThreadHandle, TaskError>

Activates a task without an external identity publication transaction.