pub struct ThreadExtensionBorrow<'thread> { /* private fields */ }Expand description
Extension identity borrowed for exactly as long as a strong thread handle.
This wrapper deliberately does not expose its copyable internal view. The strong handle borrowed by the wrapper prevents the registry reaper from destroying the extension while its opaque data is being inspected.
Implementations
Sourceimpl<'thread> ThreadExtensionBorrow<'thread>
impl<'thread> ThreadExtensionBorrow<'thread>