pub struct ThreadId(/* private fields */);Expand description
A thread registry identity containing a slot and reuse generation.
Implementations
Sourceimpl ThreadId
impl ThreadId
Sourcepub const fn from_parts(slot: u32, generation: u32) -> Self
pub const fn from_parts(slot: u32, generation: u32) -> Self
Creates an identifier from a registry slot and generation.
Sourcepub const fn generation(self) -> u32
pub const fn generation(self) -> u32
Returns the slot reuse generation.