pub struct ParkToken<'executor> { /* private fields */ }Expand description
Proof that the owner completed the executor-side park handshake.
Hold this value while attempting to block the owner in the task system. Its drop closes the handshake even when the park attempt is cancelled.
Implementations