Future support.
Structs
- Elapsed
- Error returned by
timeoutandtimeout_at. - Interrupted
- Error returned by
interruptible. - Timer
Future - Future returned by
sleepandsleep_until.
Enums
- Task
Error - Errors owned by task waiting and notification operations.
Traits
- Poll
IoError - Error capability required by
poll_io.
Functions
- block_
on - Blocks the current task until the given future is resolved or the task is interrupted by a signal.
- interruptible
- Makes a future interruptible.
- poll_io
- A helper to wrap a synchronous non-blocking I/O function into an asynchronous function.
- register_
irq_ waker - Registers a waker for the given domain-scoped IRQ id.
- register_
legacy_ irq_ waker - Registers a waker for a temporary legacy numeric IRQ.
- sleep
- Waits until
durationhas elapsed. - sleep_
until - Waits until the monotonic
deadlineis reached. - timeout
- Requires a
Futureto complete before the specified duration has elapsed. - timeout_
at - Requires a
Futureto complete before the specified monotonic deadline. - timeout_
at_ wall - Requires a
Futureto complete before the specified wall-clock deadline.
Type Aliases
- Task
Result - A result returned by a task-domain operation.