pub trait PollIoError {
// Required methods
fn is_would_block(&self) -> bool;
fn interrupted(error: Interrupted) -> Self;
}Expand description
Error capability required by poll_io.
The caller keeps ownership of its domain error while the task layer only asks how to recognize retryable I/O and how to publish an interruption.
Required Methods
Sourcefn is_would_block(&self) -> bool
fn is_would_block(&self) -> bool
Returns whether this error means the I/O operation should be retried.
Sourcefn interrupted(error: Interrupted) -> Self
fn interrupted(error: Interrupted) -> Self
Creates the caller’s domain error for an interrupted blocking wait.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".