pub struct TaskSystemConfig { /* private fields */ }Expand description
Immutable sizing and bandwidth policy for one task system.
Implementations
Sourceimpl TaskSystemConfig
impl TaskSystemConfig
Sourcepub const fn fair_slice_ns(self) -> u64
pub const fn fair_slice_ns(self) -> u64
Returns the fair service request.
Sourcepub const fn timing_granularity_ns(self) -> u64
pub const fn timing_granularity_ns(self) -> u64
Returns the scheduler timing granularity used to bound EEVDF lag.
Sourcepub const fn balance_interval_ns(self) -> u64
pub const fn balance_interval_ns(self) -> u64
Returns the balancing interval.
Sourcepub const fn rr_quantum_ns(self) -> u64
pub const fn rr_quantum_ns(self) -> u64
Returns the default round-robin quantum.
Sourcepub const fn rt_period_ns(self) -> u64
pub const fn rt_period_ns(self) -> u64
Returns the RT bandwidth period.
Sourcepub const fn rt_runtime_ns(self) -> u64
pub const fn rt_runtime_ns(self) -> u64
Returns the RT runtime budget.
Sourcepub const fn deadline_cap_percent(self) -> u8
pub const fn deadline_cap_percent(self) -> u8
Returns the Deadline admission cap in percent.
Sourcepub const fn thread_capacity(self) -> usize
pub const fn thread_capacity(self) -> usize
Returns the maximum number of published scheduler threads.
Sourcepub const fn batch_limit(self) -> usize
pub const fn batch_limit(self) -> usize
Returns the maximum work items processed at one safe point.
Sourcepub const fn pi_chain_limit(self) -> usize
pub const fn pi_chain_limit(self) -> usize
Returns the maximum owner-chain depth of one PI graph transaction.
Sourcepub const fn with_deadline_cap_percent(self, percent: u8) -> Self
pub const fn with_deadline_cap_percent(self, percent: u8) -> Self
Overrides the Deadline admission cap.
Sourcepub const fn with_balance_interval_ns(self, interval_ns: u64) -> Self
pub const fn with_balance_interval_ns(self, interval_ns: u64) -> Self
Overrides the minimum interval between owner-CPU fair migrations.
Sourcepub const fn with_rt_bandwidth(self, period_ns: u64, runtime_ns: u64) -> Self
pub const fn with_rt_bandwidth(self, period_ns: u64, runtime_ns: u64) -> Self
Enables Linux-style RT group bandwidth with an explicit period and quota.
Sourcepub const fn with_thread_capacity(self, capacity: usize) -> Self
pub const fn with_thread_capacity(self, capacity: usize) -> Self
Overrides the scheduler thread capacity prepared by every CPU.
Sourcepub const fn with_batch_limit(self, limit: usize) -> Self
pub const fn with_batch_limit(self, limit: usize) -> Self
Overrides the bounded scheduler work batch.
Sourcepub const fn with_pi_chain_limit(self, limit: usize) -> Self
pub const fn with_pi_chain_limit(self, limit: usize) -> Self
Overrides the maximum owner-chain depth of one PI graph transaction.