Stable ArceOS synchronization API.
Re-exports
pub use super::dump_lockdep_trace;Non- lockdeppub use super::set_lockdep_trace_enabled;Non- lockdep
Structs
- IrqSave
Guard - An RAII guard which saves and disables local interrupts while it is alive.
- Mutex
- A sleepable mutual-exclusion primitive.
- Mutex
Guard - An RAII guard returned by
Mutex::lockandMutex::try_lock. - Preempt
Guard - An RAII guard which disables kernel preemption while it is alive.
- Preempt
IrqSave Guard - An RAII guard which disables preemption and local interrupts.
- RawMutex
- The raw ownership and wait-queue state of a
Mutex. - Spin
Lock - A non-sleeping mutual-exclusion lock.
- Spin
RwLock - A non-sleeping read-write lock with acquisition-site context policy.
Traits
- Lockdep
Mutex Ext - Lockdep extension for structurally nested sleepable mutex acquisitions.
Type Aliases
- Lock
Subclass Non- lockdep - A lockdep subclass identifier when lockdep is disabled.
- RawSpin
Lock Guard - A guard returned by
SpinLock::lock_raw. - RawSpin
RwLock Read Guard - A raw read guard.
- RawSpin
RwLock Write Guard - A raw write guard.
- Spin
Lock Guard - A guard returned by
SpinLock::lock. - Spin
Lock IrqSave Guard - A guard returned by
SpinLock::lock_irqsave. - Spin
RwLock IrqSave Read Guard - An IRQ-save read guard.
- Spin
RwLock IrqSave Write Guard - An IRQ-save write guard.
- Spin
RwLock Read Guard - A read guard returned by
SpinRwLock::read. - Spin
RwLock Write Guard - A write guard returned by
SpinRwLock::write.