Stable ArceOS synchronization API.
Re-exports
pub use super::dump_lockdep_trace;Non- lockdeppub use super::set_lockdep_trace_enabled;Non- lockdep
Structs
- IrqSave
Guard - An RAII guard which saves and disables local interrupts while it is alive.
- Preempt
Guard - An RAII guard which disables kernel preemption while it is alive.
- Preempt
IrqSave Guard - An RAII guard which disables preemption and local interrupts.
- Spin
Lock - A non-sleeping mutual-exclusion lock.
- Spin
RwLock - A non-sleeping read-write lock with acquisition-site context policy.
Type Aliases
- RawSpin
Lock Guard - A guard returned by
SpinLock::lock_raw. - RawSpin
RwLock Read Guard - A raw read guard.
- RawSpin
RwLock Write Guard - A raw write guard.
- Spin
Lock Guard - A guard returned by
SpinLock::lock. - Spin
Lock IrqSave Guard - A guard returned by
SpinLock::lock_irqsave. - Spin
RwLock IrqSave Read Guard - An IRQ-save read guard.
- Spin
RwLock IrqSave Write Guard - An IRQ-save write guard.
- Spin
RwLock Read Guard - A read guard returned by
SpinRwLock::read. - Spin
RwLock Write Guard - A write guard returned by
SpinRwLock::write.