pub struct WaitQueueWakeToken { /* private fields */ }Expand description
An exact wake capability for one externally registered task waiter.
Composite wait sources use this token to place task waiters and non-task callbacks in one externally ordered exclusive queue. The token contains no general thread handle and is valid only for its park generation.
Implementations
Sourceimpl WaitQueueWakeToken
impl WaitQueueWakeToken
Sourcepub fn notify(&self) -> WaitQueueWakeOutcome
pub fn notify(&self) -> WaitQueueWakeOutcome
Selects one exact registered waiter with ordinary task-context intent.
Sourcepub fn notify_sync(&self) -> WaitQueueWakeOutcome
pub fn notify_sync(&self) -> WaitQueueWakeOutcome
Selects one exact registered waiter with Linux WF_SYNC intent.