ThreadExtensionBorrow

Struct ThreadExtensionBorrow 

pub struct ThreadExtensionBorrow<'thread> { /* private fields */ }
Extension identity borrowed for exactly as long as a strong thread handle.

This wrapper deliberately does not expose its copyable internal view. The strong handle borrowed by the wrapper prevents the registry reaper from destroying the extension while its opaque data is being inspected.

Implementations

Source

impl<'thread> ThreadExtensionBorrow<'thread>

pub const fn data(&self) -> usize

Returns the borrowed opaque data value.

pub const fn ops(&self) -> &'static ThreadExtensionOps

Returns the callback table used as the extension type identity.