pub struct ThreadSpec { /* private fields */ }Expand description
Validated inputs used to create a scheduler thread record.
Implementations
Sourceimpl ThreadSpec
impl ThreadSpec
Sourcepub const fn new(policy: SchedulePolicy) -> Self
pub const fn new(policy: SchedulePolicy) -> Self
Creates a thread specification with full topology affinity.
Sourcepub fn with_affinity(self, affinity: CpuSet) -> Self
pub fn with_affinity(self, affinity: CpuSet) -> Self
Restricts the thread to an explicit CPU set.
Sourcepub fn with_extension(self, extension: ThreadExtension) -> Self
pub fn with_extension(self, extension: ThreadExtension) -> Self
Attaches OS-specific state.
Sourcepub unsafe fn with_resources(self, resources: ThreadResources) -> Self
pub unsafe fn with_resources(self, resources: ThreadResources) -> Self
Associates a complete runtime resource bundle with the thread.
Safety
resources must satisfy ThreadResources::new and must be consumed by
exactly this specification and its eventual scheduler record.
Sourcepub const fn policy(&self) -> SchedulePolicy
pub const fn policy(&self) -> SchedulePolicy
Returns the base scheduling policy.