pub trait ClockEventControl {
// Required method
fn request_local_reprogram(deadline_nanos: u64);
}Expand description
Publishes an earlier local deadline to the physical clockevent owner.
Implementations may conservatively leave an already-programmed later edge pending, but must never move another CPU’s comparator or execute timer payloads from this call.
Required Methods
Sourcefn request_local_reprogram(deadline_nanos: u64)
fn request_local_reprogram(deadline_nanos: u64)
Requests that the calling CPU observe deadline_nanos.
The deadline is an absolute finite monotonic-clock value. This method is called only after the logical timer-base lock has been released.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".